==> enterprisemodules-github_config-1.1.0.tar.gz: enterprisemodules-github_config-1.1.0/lib/puppet/type/github_deploy_key.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent.parent.parent + 'easy_type' + 'lib')
require 'easy_type'
require 'puppet/property/boolean'
require 'puppet/parameter/boolean'
require 'puppet_x/enterprisemodules/github/access'

Puppet::Type.newtype(:github_deploy_key) do
  include EasyType
  extend EasyType::Encryption
  include Puppet_X::EnterpriseModules::GitHub

  desc <<-EOD
  Allows you to manage github depoloy_keys. You can specify one or more deploy_keys
  to a repository. Here is an example:

      github_deploy_key { 'authentication/owner/repo:key_name':
        ensure    => 'present',
        key       => 'ssh-rsa XXXXB3NzaC5yc2EXXXXDAQABXXABAQDgrJyY5r+jfg+J5/nagq46UFVSwCLFwMh3UClkNTBxseuMxSa+GTBmeBnTDJySq5QxaCPj6P3oIIOUhjWZcjXo7MxAMXeTiPaMDQH9q8NJGiXhP19UDvEQMllHZG6qJmSNxAWkrFAIDxLO03AQYkYYoZSwF3lqcWQhCNtiRiCq2ivWBoRgotfXa6muo3yVvvsHVQnv9EojyfBdCxBZmRnRY9cAXGBQ2fx9TFba3cURgH9T9q2E6rB6TRI0jVDwvmdL/wLQPrNxUBD8lxd/uk4cE45emMFtQm0Hu4D/zlQLNarsiBhIaFFFOqIW+SJvmYipL6YxDX+huFdDrlfhFmwp',
        read_only => 'false',
      }

  When you are specifying a diferent key or change the `read_only` property, under
  the hood puppet will delete the key and create a new one.

  EOD

  ensurable

  on_prefetch do |resources, provider|
    resources_in(resources, provider) do |repo, credentials|
      deploy_keys(repo).collect { |e| e.to_hash.merge(:name => "#{credentials}/#{repo}:#{e.title}") }
    end
  end

  to_get_raw_resources do
    values = []
    with_all_credentials do |credentials|
      values << repositories.collect do |repo|
        name      = repo[:full_name]
        full_name = "#{credentials}/#{repo[:full_name]}"
        Puppet.debug "Fetching deployment keys for #{full_name}"
        deploy_keys(name).collect { |e| e.to_hash.merge(:repo => full_name) }
      end.flatten
    end
    values.flatten
  end

  on_create do
    authenticated_with(credentials) do
      add_deploy_key(full_name, deploy_key, key, :read_only => read_only)
    end
  end

  on_modify do
    authenticated_with(credentials) do
      remove_deploy_key(full_name, provider.id)
      add_deploy_key(full_name, deploy_key, key, :read_only => read_only)
    end
  end

  on_destroy do
    authenticated_with(credentials) do
      remove_deploy_key(full_name, provider.id)
    end
  end

  map_titles_to_attributes([/((.*)\/(.*)\/(.*)\:(.*))/, [:name, :credentials, :owner, :repository, :deploy_key]])

  parameter :id
  parameter :name
  parameter :credentials
  parameter :owner
  parameter :repository
  parameter :deploy_key

  property :key
  property :read_only

end

==> enterprisemodules-github_config-1.3.0.tar.gz: enterprisemodules-github_config-1.3.0/lib/puppet/type/github_deploy_key.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
require 'easy_type'
require 'puppet/property/boolean'
require 'puppet/parameter/boolean'
require 'puppet_x/enterprisemodules/github/access'

Puppet::Type.newtype(:github_deploy_key) do
  include EasyType
  extend EasyType::Encryption
  include Puppet_X::EnterpriseModules::GitHub

  desc <<-DESCR
  Allows you to manage github depoloy_keys. You can specify one or more deploy_keys
  to a repository. Here is an example:

      github_deploy_key { 'authentication/owner/repo:key_name':
        ensure    => 'present',
        key       => 'ssh-rsa XXXXB3NzaC5yc2EXXXXDAQABXXABAQDgrJyY5r+jfg+J5/nagq46UFVSwCLFwMh3UClkNTBxseuMxSa+GTBmeBnTDJySq5QxaCPj6P3oIIOUhjWZcjXo7MxAMXeTiPaMDQH9q8NJGiXhP19UDvEQMllHZG6qJmSNxAWkrFAIDxLO03AQYkYYoZSwF3lqcWQhCNtiRiCq2ivWBoRgotfXa6muo3yVvvsHVQnv9EojyfBdCxBZmRnRY9cAXGBQ2fx9TFba3cURgH9T9q2E6rB6TRI0jVDwvmdL/wLQPrNxUBD8lxd/uk4cE45emMFtQm0Hu4D/zlQLNarsiBhIaFFFOqIW+SJvmYipL6YxDX+huFdDrlfhFmwp',
        read_only => 'false',
      }

  When you are specifying a diferent key or change the `read_only` property, under
  the hood puppet will delete the key and create a new one.

  DESCR

  ensurable

  on_prefetch do |resources, provider|
    resources_in(resources, provider) do |repo, credentials|
      deploy_keys(repo).collect { |e| e.to_hash.merge(:name => "#{credentials}/#{repo}:#{e.title}") }
    end
  end

  to_get_raw_resources do
    values = []
    with_all_credentials do |credentials|
      values << repositories.collect do |repo|
        name      = repo[:full_name]
        full_name = "#{credentials}/#{repo[:full_name]}"
        Puppet.debug "Fetching deployment keys for #{full_name}"
        deploy_keys(name).collect { |e| e.to_hash.merge(:repo => full_name) }
      end.flatten
    end
    values.flatten
  end

  on_create do
    authenticated_with(credentials) do
      add_deploy_key(full_name, deploy_key, key, :read_only => read_only)
    end
  end

  on_modify do
    authenticated_with(credentials) do
      remove_deploy_key(full_name, provider.id)
      add_deploy_key(full_name, deploy_key, key, :read_only => read_only)
    end
  end

  on_destroy do
    authenticated_with(credentials) do
      remove_deploy_key(full_name, provider.id)
    end
  end

  map_titles_to_attributes([%r{((.*)/(.*)/(.*):(.*))}, [:name, :credentials, :owner, :repository, :deploy_key]])

  parameter :id
  parameter :name
  parameter :credentials
  parameter :owner
  parameter :repository
  parameter :deploy_key

  property :key
  property :read_only
end
